<?php 

if(!defined('ABSPATH')) exit;

class Woo_Psb_Method extends WC_Shipping_Method {
	private $mdata;
	private $service;
	private $cod;
	private $carrier;

	public function __construct($meth_id, $meth_data) {
		list($s_id, $cod) = explode(',', $meth_id);
		$this->instance_id = $s_id * 10 + $cod;
		$this->id = 'psb_' . str_replace(',', '_', $meth_id);
		$this->service = $s_id;
		$this->cod = $cod;
		$this->carrier = $meth_data['carrier'];
		$this->method_title = $meth_data['dname'] ? $meth_data['dname'] : $meth_data['name'];
		$this->tax_status = 'none';
		$this->init($meth_data);
	}
	
	private function init($data) {
		//$this->title = $this->get_option('title');
		$this->title = $this->method_title;
		$this->flat_rate = true;
		$this->mdata = $data;
		$this->init_form_fields();
		add_filter('woocommerce_cart_shipping_method_full_label', array($this, 'woocommerce_cart_shipping_method_full_label'), 10, 2);
        add_filter('woocommerce_order_shipping_to_display_shipped_via', array($this, 'woocommerce_order_shipping_to_display_shipped_via'), 10, 2);
		add_action('add_meta_boxes', array($this, 'add_meta_boxes'), 10, 2);
		add_action('woocommerce_checkout_process', array($this, 'woocommerce_checkout_process'));
		if(in_array($this->service, Psb_Api::$paczkomatowe)) {
		    add_action('woocommerce_review_order_after_shipping', array($this, 'woocommerce_review_order_after_shipping'));
    		add_action('woocommerce_checkout_update_order_meta', array($this, 'woocommerce_checkout_update_order_meta'));
		}
	}
	
	public function calculate_shipping($package = array()) {
		$add_rate = array(
			'id' => $this->id,
			'label' => $this->title,
			'cost' => $this->mdata['price'],
			'taxes' => false
		);
		$this->add_rate($add_rate);
		return true;
	}

	public function init_form_fields() {
		$settings = array(
			'title' => array(
				'title' => 'Nazwa metody',
				'type' => 'text',
				'default' => $this->method_title,
				'desc_tip' => false
			)				
		);
		$this->form_fields = $settings;
	}

	public function add_meta_boxes($post_type, $post) {
		if ($post->post_type == 'shop_order') {
			$order = wc_get_order($post->ID);
			if($order->has_shipping_method($this->id)) {
				add_meta_box(
					'psb_' . str_replace(',', '_', $this->id),
					'Patron Service Broker' . $this->get_logo(),
					array($this, 'order_metabox'),
					'shop_order',
					'normal',
					'default'
				);
			}
		}
	}

	function woocommerce_cart_shipping_method_full_label($label, $method) {
		if($method->id == $this->id) {
			$img = ' <span class="psb-shipping-method-logo"><img style="" src="' . plugin_dir_url(__FILE__) . '../img/logo.png' . '">';
			$label .= $img;
		}
		return $label;
	}
	
	function woocommerce_order_shipping_to_display_shipped_via($via, $order) {
		if($order->has_shipping_method($this->id)) {
			$img = ' <span class="psb-shipping-method-logo" style="display: inline;"><img style"max-height: 32px; display: inline; border:none;" src="' . plugin_dir_url(__FILE__) . '../img/logo.png' . '">'; 
            $via .= $img;
        }
        return $via;
    }
	
	public function get_logo() {
		return '<img style="height:32px; float:right;" src="' . plugin_dir_url(__FILE__) . '../img/logo.png' . '">';
	}
	
	public function order_metabox($post) {
		wp_enqueue_script('psb_admin_order', plugin_dir_url(__FILE__) . '../js/order.js');
		wp_enqueue_style('psb_admin_order', plugin_dir_url(__FILE__) . '../css/order.css');
		
		$id_order = $post->ID;
		$order = wc_get_order($id_order);
		$meta = get_post_meta($id_order, '_psb_data', true);
		
		$img_uri = plugin_dir_url(__FILE__) . '../img';
		$token = wp_create_nonce('psb_nonce');
		$id_label = $meta ? $meta['api_id'] : '';
		$track = $meta ? Psb_Api::genTrackLink($meta['api_id']) : '';
		$service = $this->service;
		$paczkomatowa = in_array($service, Psb_Api::$paczkomatowe);
		$cod = $this->cod;
		$carrier = $this->carrier;
		$name = $this->method_title;
		$cod_amount = $this->cod ? $order->total : 0;
		$insurance = $this->cod ? $order->total : get_option('psb_def_ins');
		$weight = get_option('psb_def_weight');
		$height = get_option('psb_def_height');
		$length = get_option('psb_def_length');
		$width = get_option('psb_def_width');
		$locker_id = get_post_meta($id_order, '_psb_sellocker', true);
		$locker_d1 = get_post_meta($id_order, '_psb_sellocker_d1', true);
		$locker_d2 = get_post_meta($id_order, '_psb_sellocker_d2', true);
		$nst = 0;
		$tmp = get_option('psb_slocker');
		if($tmp != '') list($smode, $slocker) = unserialize($tmp);
		else {
		    $smode = 1;
		    $slocker = array('', '', '');
		}
		if(!$smode) $smode = 1;
		include dirname(__FILE__) . '/../views/order.php';
	}

	public function woocommerce_checkout_process() {
		$sm = WC()->session->get('chosen_shipping_methods');
		if(($sm != null) && in_array($this->id, $sm)) {
      		$phone = trim($_POST['billing_phone']);
      		if(substr($phone, 0, 3) == '+48') $phone = substr($phone, 3);
        	if(strlen($phone) != 9) {
        		wc_add_notice('Metoda dostawy wymaga podania prawidłowego telefonu', 'error' );
        	}
        	if(in_array($this->service, Psb_Api::$paczkomatowe)) {
        	    if(!isset($_POST['psb_sellocker']) || ($_POST['psb_sellocker'] == '')) {
            	   wc_add_notice('Metoda dostawy wymaga wybrania paczkomatu', 'error' );
            	}
            	else {
        	       WC()->session->set('locker_id', $_POST['psb_sellocker']);
        	       WC()->session->set('locker_d1', $_POST['psb_sellocker_d1']);
        	       WC()->session->set('locker_d2', $_POST['psb_sellocker_d2']);
            	}
		    }
        	$pm = $_POST['payment_method'];
        	if($this->cod && ($pm != 'cod')) wc_add_notice('Dla tej metody dostawy wybierz płatność za pobraniem', 'error' );
        	if(!$this->cod && ($pm == 'cod')) wc_add_notice('Dla tej metody dostawy wybierz inną metodę płatności', 'error' );
        }
	}

	public function woocommerce_review_order_after_shipping() {
	    if(in_array($this->id, WC()->session->get('chosen_shipping_methods'))) {
	        $locker_id = WC()->session->get('locker_id');
	        $locker_d1 = WC()->session->get('locker_d1');
	        $locker_d2 = WC()->session->get('locker_d2');
	        include dirname(__FILE__) . '/../views/cart.php';
	    }
	}
	
	public function woocommerce_checkout_update_order_meta( $order_id ) {
	    if($_POST['psb_sellocker']) {
	        update_post_meta($order_id, '_psb_sellocker', esc_attr($_POST['psb_sellocker']));
	        update_post_meta($order_id, '_psb_sellocker_d1', esc_attr($_POST['psb_sellocker_d1']));
	        update_post_meta($order_id, '_psb_sellocker_d2', esc_attr($_POST['psb_sellocker_d2']));
	    }
	}
	
}

?>