<?php 

if(!defined('ABSPATH')) exit;

class Psb_Settings extends WC_Settings_Page {

	public $id;
	
	public function __construct() {
		$this->id = 'psb_settings';
		$this->label = 'Patron Service Broker';

		add_filter('woocommerce_settings_tabs_array', array($this, 'add_settings_page'), 20);
		add_action('woocommerce_settings_' . $this->id, array($this, 'output'));
		add_action('woocommerce_settings_save_' . $this->id, array($this, 'save'));
	}
	
	public function output() {
		$settings = $this->get_settings();
		WC_Admin_Settings::output_fields($settings);
		$img_uri = plugin_dir_url(__FILE__) . '../img';
		$token = wp_create_nonce('psb_nonce');
		?>
		<script type="text/javascript">
		var psb_serv;

		jQuery(document).ready(function(){
			var html = '<button class="button" id="psb_get_servs" type="button">Pobierz listę usług z API</button><div id="ajax_running" style="display: none;"><img style="width: 30px;" src="<?= $img_uri ?>/busy.gif"></div><div id="patronbroker_msg_container"></div><br/><br/>';
			jQuery('#psb_serv').before(html);
			psb_read();
			jQuery('#psb_get_servs').click(function(){
				psb_get_servs();
			});			
		});

		function psb_read() {
			if(jQuery('#psb_serv').val() != '')
				psb_serv = JSON.parse(jQuery('#psb_serv').val());
			else
				psb_serv = [];
			var html = '<table class="psb_price_tab" style="background: #d0d0d0; padding: 5px; display: none;"><thead><tr><th>Usługa</th><th>Cena</th><th>Cena COD</th><th>Nazwa wyświetlana</th></tr></thead><tbody>';
			var dname = '';
			Object.keys(psb_serv).sort().forEach(key => {
				if(psb_serv[key]['del'] == 0) {
					var t = key.split(',');
					var psb_id = 'psb_serv_p_' + t[0] + '_' + t[1];
					if(t[1] == 0) {
						if(psb_serv[key]['dname']) dname = psb_serv[key]['dname'];
						else dname = psb_serv[key]['name'];
						html += '<tr><td>' + psb_serv[key]['name'] + '</td><td><input class="psb_serv_p" type="text" name="' + psb_id + '" id="' + psb_id + '" size="5" value="' + psb_serv[key]['price'] + '"></td>';
					}
					if(t[1] == 1) html += '<td><input class="psb_serv_p" type="text" name="' + psb_id + '" id="' + psb_id + '" size="5" value="' + psb_serv[key]['price'] + '"></td><td><input class="psb_serv_n" type="text" name="psb_serv_n_' + t[0] + '" id="psb_serv_n_' + t[0] + '" size="30" value="' + dname + '"></td></tr>';
				}
			});
			html += '</tbody></table>';
			jQuery('#psb_serv').after(html);
			jQuery('.psb_price_tab').slideDown();

			jQuery('.psb_serv_p').change(function(){
				psb_update(this);
			});
			jQuery('.psb_serv_n').change(function(){
				psb_update_n(this);
			});
		}

		function psb_update(inp) {
			var t = jQuery(inp).attr('id').split('_');
			psb_serv[t[3] + ',' + t[4]]['price'] = jQuery(inp).val();
			jQuery('#psb_serv').val(JSON.stringify(psb_serv));
		}

		function psb_update_n(inp) {
			var t = jQuery(inp).attr('id').split('_');
			psb_serv[t[3] + ',0']['dname'] = jQuery(inp).val();
			psb_serv[t[3] + ',1']['dname'] = jQuery(inp).val() + ' (pobranie)';
			jQuery('#psb_serv').val(JSON.stringify(psb_serv));
		}

		function psb_get_servs() {
			jQuery('#ajax_running').slideDown();
			jQuery('#patronbroker_msg_container').slideUp().html('');
			
		    var data = {
				'action': 'psb_ajax',
				'psb_action': 'getServs',
				'psb_token': '<?= $token ?>',
				'psb_user': jQuery('#psb_api_login').val(),
				'psb_pass': jQuery('#psb_api_pass').val(),
				'psb_url': jQuery('#psb_api_url').val(),
				'psb_data': JSON.stringify(psb_serv)
			};
			jQuery.post(ajaxurl, data, function(response) {
				if(response != 0) {
		            var resp = JSON.parse(response);
		            if(resp.error) {
		            	jQuery('#patronbroker_msg_container').hide().html('<p class="psb-error">'+resp.error+'</p>').slideDown();
		            }
		            else {
		            	psb_serv = resp.data;
		            	jQuery('#psb_serv').val(JSON.stringify(psb_serv));
		            	jQuery('.psb_price_tab').slideDown();
		            	jQuery('.psb_price_tab').remove();
		            	psb_read();
		            }
				}
				else {
					jQuery('#patronbroker_msg_container').hide().html('<p class="psb-error">Błąd komunikacji (1)</p>').slideDown();
				}
				jQuery('#ajax_running').slideUp();
			})
			.fail(function (jqXHR, textStatus, errorThrown) {
				jQuery('#patronbroker_msg_container').hide().html('<p class="psb-error">Błąd komunikacji (2)</p>').slideDown();
				jQuery('#ajax_running').slideUp();
			});
		};
				
		</script>
		<?php
	}

	public function save() {
		$settings = $this->get_settings();
		WC_Admin_Settings::save_fields($settings);
	}

	public function get_settings() {
		$settings = array(
			array('title' => 'Dostęp do API', 'type' => 'title', 'desc' => '', 'id' => 'api_options'),
			array(
				'title' => 'Url',
				'id' => 'psb_api_url',
				'css' => 'min-width:300px;',
				'default' => Psb_Api::psb_testurl,
				'type' => 'text',
				'desc_tip' => 'Po uzyskaniu z Patron Broker Service loginu i hasła zmień url na ' . Psb_Api::psb_produrl,
				'custom_attributes' => array('required' => 'required')
			),
			array(
				'title' => 'Login',
				'id' => 'psb_api_login',
				'css' => 'min-width:300px;',
				'default' => 'demo',
				'type' => 'text',
				'desc_tip' =>  false,
				'custom_attributes' => array('required' => 'required'),
			),	
			array(
				'title' => 'Hasło',
				'id' => 'psb_api_pass',
				'css' => 'min-width:300px;',
				'default' => 'demo',
				'type' => 'text',
				'desc_tip' =>  false,
				'custom_attributes' => array('required' => 'required'),
			),
			array('type' => 'sectionend', 'id' => 'api_options'),
			array('title' => 'Usługi', 'type' => 'title', 'desc' => '', 'id' => 'serv_options'),
			array(
				'title' => '',
				'id' => 'psb_serv',
				'css' => 'display: none;',
				'default' => json_encode(array('172,0' => array('name' => 'Patron Service', 'price' => 10, 'carrier' => 'patron', 'del' => 0), '172,1' => array('name' => 'Patron Service (pobranie)', 'price' => 12, 'carrier' => 'patron', 'del' => 0))),
				'type' => 'textarea',
				'desc_tip' =>  false,
				'custom_attributes' => array(),
			),
			array('type' => 'sectionend', 'id' => 'serv_options'),
			array('title' => 'Parametry paczki', 'type' => 'title', 'desc' => '', 'id' => 'pack_options'),
			array(
				'title' => 'Domyślna kwota ubezpieczenia',
				'id' => 'psb_def_ins',
				'css' => 'min-width:300px;',
				'default' => '0',
				'type' => 'number',
				'desc_tip' =>  false,
				'custom_attributes' => array('required' => 'required', 'step'  => 0.01, 'min'   => '0')
			),
			array(
				'title' => 'Domyślna waga (kg)',
				'id' => 'psb_def_weight',
				'css' => 'min-width:300px;',
				'default' => '1',
				'type' => 'number',
				'desc_tip' =>  false,
				'custom_attributes' => array('required' => 'required'),
			),
			array(
				'title' => 'Domyślna wysokość (cm)',
				'id' => 'psb_def_height',
				'css' => 'min-width:300px;',
				'default' => '10',
				'type' => 'number',
				'desc_tip' =>  false,
				'custom_attributes' => array('required' => 'required'),
			),
			array(
				'title' => 'Domyślna długość (cm)',
				'id' => 'psb_def_length',
				'css' => 'min-width:300px;',
				'default' => '20',
				'type' => 'number',
				'desc_tip' =>  false,
				'custom_attributes' => array('required' => 'required'),
			),
			array(
				'title' => 'Domyślna szerokość (cm)',
				'id' => 'psb_def_width',
				'css' => 'min-width:300px;',
				'default' => '10',
				'type' => 'number',
				'desc_tip' =>  false,
				'custom_attributes' => array('required' => 'required'),
			),
			array('type' => 'sectionend', 'id' => 'pack_options'),
			array('title' => 'Dane nadawcy', 'type' => 'title', 'desc' => '', 'id' => 'sender_options'),
			array(
				'title' => 'Nazwa',
				'id' => 'psb_sender_name',
				'css' => 'min-width:300px;',
				'default' => '',
				'type' => 'text',
				'desc_tip' =>  false,
				'custom_attributes' => array('required' => 'required'),
			),
			array(
				'title' => 'Adres',
				'id' => 'psb_sender_adr',
				'css' => 'min-width:300px;',
				'default' => '',
				'type' => 'text',
				'desc_tip' =>  false,
				'custom_attributes' => array('required' => 'required'),
			),
			array(
				'title' => 'Miasto',
				'id' => 'psb_sender_city',
				'css' => 'min-width:300px;',
				'default' => '',
				'type' => 'text',
				'desc_tip' =>  false,
				'custom_attributes' => array('required' => 'required'),
			),
			array(
				'title' => 'Kod pocztowy',
				'id' => 'psb_sender_code',
				'css' => 'min-width:300px;',
				'default' => '',
				'type' => 'text',
				'desc_tip' =>  false,
				'custom_attributes' => array('required' => 'required'),
			),
			array(
				'title' => 'Osoba',
				'id' => 'psb_sender_person',
				'css' => 'min-width:300px;',
				'default' => '',
				'type' => 'text',
				'desc_tip' =>  false,
				'custom_attributes' => array('required' => 'required'),
			),
			array(
				'title' => 'Telefon',
				'id' => 'psb_sender_phone',
				'css' => 'min-width:300px;',
				'default' => '',
				'type' => 'tel',
				'desc_tip' =>  false,
				'custom_attributes' => array('required' => 'required'),
			),
			array(
				'title' => 'Email',
				'id' => 'psb_sender_email',
				'css' => 'min-width:300px;',
				'default' => '',
				'type' => 'email',
				'desc_tip' =>  false,
				'custom_attributes' => array('required' => 'required'),
			),
			array('type' => 'sectionend', 'id' => 'sender_options'),
		);
		
		return $settings;
	}	
	
}

?>