<?php

/**
* Plugin Name: Patron Broker
* Developer: Marcin Bogdański
* Author: Marcin Bogdański (Opennet)
* Author URI: http://opennet.pl/
* Version: 1.3
* Description: Kurier Patron Broker dla WooCommerce
*/

if(!defined('ABSPATH')) exit;
//include 'conf.php';

class PsbPlugin {

	public static $instance;
	private $shipping_methods = array();
	
	public function __construct() {
		add_action('plugins_loaded', array($this, 'init'), 100);
	}
	
	public static function PsbPlugin() {
		if (self::$instance === null) {
			self::$instance = new self();
		}
		return self::$instance;
	}
	
	public function init() {
		include 'classes/method.php';
		include 'classes/ajax.php';
		include 'classes/api.php';
		$this->init_shipping_methods();
		Psb_Ajax::init();
	
		add_filter('woocommerce_get_settings_pages', array($this, 'woocommerce_get_settings_pages'));	
        add_filter('woocommerce_shipping_methods', array( $this, 'woocommerce_shipping_methods'));
        add_filter('plugin_action_links_' . plugin_basename(__FILE__), array($this, 'linksFilter'));
        add_action('wp_footer', array($this, 'footer'), 75 );
        add_action('admin_footer', array($this, 'footer'), 75 );
        add_action('admin_enqueue_scripts', array($this, 'enqueue_scripts'), 75);        
        add_action('wp_enqueue_scripts', array($this, 'enqueue_scripts'), 75);
	}

	public function init_shipping_methods() {
	    if(!get_option('psb_serv')) return;
		$serv = json_decode(get_option('psb_serv'), true);
		foreach($serv as $id => $data) {
			if(($data['price'] != 0) && !$data['del']) {
				$meth = new Woo_Psb_Method($id, $data);
				$this->shipping_methods[] = $meth;
			}
		}
	}

	public function woocommerce_shipping_methods($methods) {
		foreach($this->shipping_methods as $shipping_method) {
			$methods[] = $shipping_method;
		}
		return $methods;
	}

	public function woocommerce_get_settings_pages($woocommerce_settings) {
		include('classes/settings.php');
		$settings = new Psb_Settings();
		$woocommerce_settings[] = $settings;
		return $woocommerce_settings;
	}
	
	public function linksFilter($links) {
		$plugin_links = array(
			'<a href="' . admin_url('admin.php?page=wc-settings&tab=psb_settings') . '">Ustawienia</a>'
        );
        return array_merge($plugin_links, $links);
    }

    function getEasypack() {
        return (trim(get_option('psb_api_url')) == Psb_Api::psb_produrl) ? 'https://geowidget.easypack24.net' : 'http://sandbox-geowidget.easypack24.net';
    }

    public function footer() {
        echo '<script async src="' . $this->getEasypack() . '/js/sdk-for-javascript.js"></script>';    
    }
   
    function enqueue_scripts() {
        wp_enqueue_style('geowidget-css', $this->getEasypack() . '/css/easypack.css');
    }

}

function PsbPlugin() {
	return PsbPlugin::PsbPlugin();
}

$_GLOBALS['PsbPlugin'] = PsbPlugin();
